.. PySUS documentation master file, created by
   sphinx-quickstart on Thu Aug 25 10:37:19 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PySUS's documentation!
=================================

PySUS is a library which is a collection of helper codes for people which need to analyze data from SUS (Brazilian Universal
Health System). Contributions are welcome!

Contents:

.. toctree::
   :maxdepth: 2

   Data Sources <data-sources>
   Tutorials <tutorials>
   Loading SINAN data <SINAN.ipynb>
   Loading SIM data <SIM.ipynb>
   Loading SIA data <Analyzing SIA.ipynb>
   LOADING PNI data <PNI.ipynb>
   Analyzing Dengue data <Dengue.ipynb>
   Analyzing Chikungunya data <Chikungunya.ipynb>
   Analyzing Zika data <Zika.ipynb>
   Downloading COVID data from ESUS <ESUS.ipynb>
   Manipulating Demographic Data <Demography.ipynb>
   Getting Official Statistics <IBGE_data.ipynb>




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

